unit uMHA_DLL;

{*

Compiling instructions:
  The "InternalName" field in the Version Information contains the
  version of the MHA server that this dll works with.
  1.0.2.20

*}

interface

uses
  windows,
  Classes,
  Graphics,
  forms,
  dialogs,
  SysUtils,
  ComCtrls,
  Trpcb;

procedure ShowInstrument(Broker: TRPCBroker;
  InstrumentName,
  PatientDFN,
  OrderedBy,
  OrderedByDUZ,
  AdministeredBy,
  AdministeredByDUZ,
  Location,
  LocationIEN: string; // Add a "V" for Vista storage of temp file
  AllQuestionsRequired: Boolean;
  var ReturnString: string); stdcall;

procedure SaveInstrument(Broker: TRPCBroker;
  InstrumentName,
  PatientDFN,
  OrderedByDUZ,
  AdministeredByDUZ,
  AdminDate, // FileMan format
  LocationIEN: string; // Add a "V" for Vista storage of temp file
  var Status: string); stdcall;

procedure RemoveTempFile(
  InstrumentName, // if blank, all instruments are removed for patient
  PatientDFN: string); stdcall;

procedure RemoveTempVistaFile(
  Broker: TRPCBroker;
  InstrumentName, // if blank, all instruments are removed for patient
  PatientDFN: string); stdcall;

procedure CloseDLL; stdcall;

implementation

uses
  System.Contnrs,
  uIA_Const,
  uMHA_DLL_Const,
  uMHA_DLL_Registry,
  uIA_Utils,
  uIA_Answer,
  uIA_Instrument,
  uMHA_DLL_Instrument_OPS,
  uIA_Patient,
  uIA_Patient_OPS,
  uIA_Question,
  uIA_Introduction,
  fMHA_DLL_DataEntry,
  uMHA_DLL_Vista_IO,
  uMHA_DLL_Score_IO,
  fMHA_DLL_GAF,
  uMHA_DLL_GAF_List,
  uMHA_DLL_GAF_IO,
  fIA_Dialogs;

var
  lvDataEntry_Handle          : HWND = 0;


procedure UponClosing(Broker: TRPCBroker);
begin
  ReturnContextToCPRS(Broker);
end;

function BuildLegacyScoreString(Broker: TRPCBroker): string;
var
  i                           : Integer;
  LegacyAnswerString          : string;
begin
  Result := '';
  LegacyAnswerString := '';

  for i := 0 to gvInstrument.ListOfAnswers.Count - 1 do
    begin
      LegacyAnswerString := LegacyAnswerString +
        TAnswer(gvInstrument.ListOfAnswers[i]).AnswerLegacyValue;
    end; // for i

  result := GetLegacyScores(Broker, //uMHA_DLL_ReportIO
    gvInstrument.InstrumentName,
    DateStrToFMDateStr(DateToStr(Now)),
    Patient.DFN,
    gvOrderedByDUZ,
    LegacyAnswerString);

end;

function GetTempDir: string;
var
  lng                         : DWORD;
  thePath                     : string;
begin
  SetLength(thePath, MAX_PATH);
  lng := GetTempPath(MAX_PATH, PChar(thePath));
  SetLength(thePath, lng);
  result := thepath;

end;

function GetFileName(PatientDFN, InstrumentName: string): string;
begin
  Result := GetTempDir +
    IntToStr(DateTimeToFileDate(Date)) +
    FILE_NAME_DELIMITER +
    PatientDFN + FILE_NAME_DELIMITER +
    InstrumentName + '.mha';
    // The "mha" extension is not used by any other system according to a search
    // on the web.
end;


function HandleGAF(Broker: TRPCBroker): string;
var
  TempAns                     : TAnswer;
  TempStrList                 : TStringList;
begin
  Result := '';

  PatientGAFList := TGAF_List.Create;
  PatientGAFList.LoadRatingList(Broker, Patient.DFN);

  try
    frmMHA_DLL_GAF := TfrmMHA_DLL_GAF.Create(nil);
  finally
    frmMHA_DLL_GAF.Free;
  end; //try

  if (FinishedAs = faComplete) and (gvScoreStr <> '-1') then
    begin

      if gvSaveTempToVista then
        begin
          TempAns := TAnswer.Create;

          TempAns.QuestionID := '1';
          TempAns.AnswerValue := gvScoreStr;
          TempAns.AnswerText := '';
          TempAns.IsMultiChoice := False;

          gvInstrument.ListOfAnswers.Add(TempAns);

          WriteAnswersToTemp(Broker, Patient.DFN, gvInstrument);
        end
      else
        begin
          // Write answers to Temp File on workstation
          TempStrList := TStringList.create;
          TempStrList.Add(gvScoreStr);

          gvFileName := GetFileName(Patient.DFN, 'GAF');

          TempStrList.SaveToFile(gvFileName);
          TempStrList.Free;
        end;

      Result := 'COMPLETE' + U +
        'GAF' + U +
        '1' + U +
        '*SCORE ~ ' + gvScoreStr + U +
        'GAF Score: ' + gvScoreStr;
    end
  else
    Result := 'CANCELLED ';

  if PatientGAFList <> nil then
    PatientGAFList.Free;
end;

procedure WriteAnswersToTempFile;
var
  j                           : Integer;
  TempStrList                 : TStringList;
begin
  // Write answers to Temp File
  TempStrList := TStringList.create;

  for j := 0 to gvInstrument.ListOfAnswers.Count - 1 do
    TempStrList.Add(
      TAnswer(gvInstrument.ListOfAnswers[j]).QuestionID + U +
      TAnswer(gvInstrument.ListOfAnswers[j]).AnswerValue + U +
      TAnswer(gvInstrument.ListOfAnswers[j]).AnswerText + U +
      TAnswer(gvInstrument.ListOfAnswers[j]).AnswerLegacyValue + U +
      BoolToMStr(TAnswer(gvInstrument.ListOfAnswers[j]).IsMultiChoice) + U);

  TempStrList.SaveToFile(gvFileName);
  TempStrList.Free;

end;


procedure CloseDLL; stdcall;
// CPRS is timed out, save current work.
begin
  lvDataEntry_Handle := FindWindow('TfrmMHA_DLL_DataEntry', nil);

  if lvDataEntry_Handle <> 0 then
    begin
      FinishedAs := faInComplete;
      frmMHA_DLL_DataEntry.ShutDown;
    end;
end;

procedure RemoveFiles;
var
  SearchRec                   : TSearchRec;
  TempDir,
    TempDateStr,
    TempFileName              : string;
begin
  // Remove the current file
  DeleteFile(gvFileName);
  TempDir := GetTempDir;

  // Remove all files that do not have today's date, regardless of pt or instrument name
  TempDateStr := IntToStr(DateTimeToFileDate(Date));

  if FindFirst(TempDir + '*.mha', faAnyFile, SearchRec) = 0 then
    begin
      repeat
        TempFileName := ExtractFileName(SearchRec.Name);
        if TempDateStr <> Piece(TempFileName, FILE_NAME_DELIMITER, 1) then
          DeleteFile(TempDir + SearchRec.Name);
      until FindNext(SearchRec) <> 0;
      FindClose(SearchRec);
    end;
end;

procedure ShowInstrument(Broker: TRPCBroker;
  InstrumentName,
  PatientDFN,
  OrderedBy,
  OrderedByDUZ,
  AdministeredBy,
  AdministeredByDUZ,
  Location,
  LocationIEN: string; // Add a "V" for Vista storage of temp file
  AllQuestionsRequired: Boolean;
  var ReturnString: string); stdcall;
// The results of the Instrument are saved to a scratch file. This allows the user
// to reopen an instrument and change its responses before the final results are
// saved to Vista.
var
  i, x                        : Integer;
  lvLocationIEN,
    Reply                     : string;

  procedure ClearTheDecks;
  begin
    if gvInstrument <> nil then
      gvInstrument.Free;
    gvFont.Free;
    UponClosing(Broker);
  end;

begin
  gvFont := TFont.Create;
  gvTop := 400;
  gvLeft := 400;

  lvLocationIEN := LocationIEN;
  x := Pos('V', lvLocationIEN);
  if x > 0 then
    begin
      gvSaveTempToVista := True;
      Delete(lvLocationIEN, x, 1);
    end
  else
    gvSaveTempToVista := False;

  // Make sure the server and client are compatible
  if not CorrectVersion(Broker) then // uMHA_DLL_Vista_IO
    begin
      MsgDlgFrm(
        'The DLL was unable to load: ' + #13 +
        'The client and server version of the ' +
        'broker do not match. ' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists.',
        MHA_DLL_CAPTION, mtError, [mbOK], 0);
      ReturnString := 'CANCELLED';
      ClearTheDecks;
      Exit;
    end;

  FinishedAs := faComplete;
  gvOrderedBy := OrderedBy;
  gvAdministeredBy := AdministeredBy;
  gvOrderedByDUZ := OrderedByDUZ;
  gvAdministeredByDUZ := AdministeredByDUZ;
  gvLocation := Location;
  gvAllQuestionsRequired := AllQuestionsRequired;
  gvScoreStr := '';
  gvSkipped := '';

  ReturnString := '';

  if (PatientDFN = '') then
    begin
      MsgDlgFrm(
        'The DLL was unable to load: ' +
        'Patient DFN missing.' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists.',
        MHA_DLL_CAPTION, mtError, [mbOK], 0);
      ReturnString := 'CANCELLED';
      ClearTheDecks;
      Exit;
    end;

  Reply := Patient.Load(PatientDFN, Broker);

  if reply <> OK then
    begin
      MsgDlgFrm(
        'The DLL was unable to load: ' +
        'Patient DFN was incorrect. Close and start over.' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists.',
        MHA_DLL_CAPTION, mtError, [mbOK], 0);
      ReturnString := 'CANCELLED';
      ClearTheDecks;
      Exit;
    end;

  gvInstrument := TInstrument.Create;
  gvInstrument.InstrumentName := InstrumentName;
  // Instrument, in turn creates the Objects; Questions, Introductions, Sections,
  //   Rules, Answers, Scales and Keys.

  // GAF has its own form and procedures
  if InstrumentName = 'GAF' then
    begin
      ReturnString := HandleGAF(Broker);
      ClearTheDecks;
      Exit;
    end;

  if not DLL_Instrument_OPS.LoadDescriptiveProperties(Broker, gvInstrument) then
    begin
      ReturnString := 'Unable to load instrument-object.';
      MsgDlgFrm(
        'Sorry, a serious error has occurred. ' + #13 +
        'A call to YS Broker1, YTQ TSLIST1, produced an error. This may be ' +
        'due to not having the YS Broker1 properly set in VistA. ' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists.',
        MHA_DLL_CAPTION, mtError, [mbOK], 0);
      ReturnString := 'CANCELLED';
      ClearTheDecks;
      Exit;
    end;

  DLL_Instrument_OPS.Load(Broker, gvInstrument);

  // Make sure this person has authority to use this instrument
  if gvInstrument.R_Privilege <> '' then
    begin
      reply := ReadStaffProperties(Broker, gvOrderedByDUZ,
        gvInstrument.R_Privilege);

      if reply = '' then
        begin
          MsgDlgFrm(
            'The person who has ordered this instrument does not have the proper key.' + #13 +
            'Please contact your local IRM or CPRS expert if this ' +
            'problem persists.',
            MHA_DLL_CAPTION, mtError, [mbOK], 0);

          ReturnString := 'CANCELLED';
          ClearTheDecks;
          Exit;
        end;

      if reply = BAD_DATA then
        begin
          MsgDlgFrm(
            'The Mental Health DLL was unable to get information about ' +
            'the staff who ordered this instrument.' + #13 +
            'Please contact your local IRM or CPRS expert if this ' +
            'problem persists.',
            MHA_DLL_CAPTION, mtError, [mbOK], 0);
          ReturnString := 'CANCELLED';
          ClearTheDecks;
          Exit;
        end;
    end; // User can use this instrument

  if gvSaveTempToVista then
    ReadAnswersFromTempForObject(Broker, Patient.DFN, gvInstrument)
  else
    gvFileName := GetFileName(Patient.DFN, gvInstrument.InstrumentName);

  try
    gvBroker := Broker;
    frmMHA_DLL_DataEntry := TfrmMHA_DLL_DataEntry.Create(nil);
  finally
    frmMHA_DLL_DataEntry.Free;
  end; //try

  if FinishedAs = faCancelled then
    begin
      if gvSaveTempToVista then
        begin
          if not WriteAnswersToTemp(Broker, Patient.DFN, gvInstrument) then
            ShowMessage('Unable to save temporary list.');
        end
      else
        WriteAnswersToTempFile;

      ReturnString := 'CANCELLED' + U + gvInstrument.InstrumentName + U +
        IntToStr(gvInstrument.NumberOfQuestions) + U + U +
        gvSkipped;
    end;

  if FinishedAs = faNotStarted then
    ReturnString := 'NOT STARTED' + U + gvInstrument.InstrumentName + U +
      IntToStr(gvInstrument.NumberOfQuestions);

  if FinishedAs = faInComplete then
    begin
      ReturnString := 'INCOMPLETE' + U + gvInstrument.InstrumentName + U +
        IntToStr(gvInstrument.NumberOfQuestions) + U + U +
        gvSkipped;

      if gvSaveTempToVista then
        begin
          if not WriteAnswersToTemp(Broker, Patient.DFN, gvInstrument) then
            ShowMessage('Unable to save temporary list.');
        end
      else
        WriteAnswersToTempFile;

    end; // Incomplete

  if (FinishedAs = faComplete) then
    begin
      if gvSaveTempToVista then
        begin
          if not WriteAnswersToTemp(Broker, Patient.DFN, gvInstrument) then
            ShowMessage('Unable to save temporary list.');
        end
      else
        WriteAnswersToTempFile;

      // Format:
      //      COMPLETE ^
      //      AUDC ^
      //      4 ^
      //      *ScaleIEN1 ~ ScaleScore1 * ScaleIEN2 ~  ScaleScore2 * .. ScaleIEN_N ~ ScaleScoreN. ^
      //      *Question1 text ~ Answer1 Text * Question2 Text ~ Answer2 Text * .. QuestionN Text ~ AnswerN Text ^

      ReturnString := 'COMPLETE' + U +
        gvInstrument.InstrumentName + U +
        IntToStr(gvInstrument.NumberOfQuestions) + U;

      if (gvInstrument.R_Privilege <> '') then
        begin
          ReturnString := ReturnString + '*' +
            'Restricted instrument. No results are reported here.';
          ClearTheDecks;
          exit;
        end;

      // Scores: Legacy instruments use a special call to get scores
      if gvInstrument.IsLegacy then
        ReturnString := ReturnString +
          BuildLegacyScoreString(Broker) + U
      else
        ReturnString := ReturnString + gvScoreStr + U;

      // Questions and Answers
      if ((gvInstrument.R_Privilege = '') and
        (gvInstrument.WriteFullText)) then
        for i := 0 to gvInstrument.ListOfAnswers.Count - 1 do
          ReturnString := ReturnString + '*' +
            TQuestion(gvInstrument.ListOfQuestions[i]).qCaption + '~' +
            RemoveControlChar(TAnswer(gvInstrument.ListOfAnswers[i]).AnswerText)
      else
        for i := 0 to gvInstrument.ListOfAnswers.Count - 1 do
          ReturnString := ReturnString + '*' +
            TQuestion(gvInstrument.ListOfQuestions[i]).Designator + '~' +
            TAnswer(gvInstrument.ListOfAnswers[i]).AnswerLegacyValue;
    end; // Complete

  ClearTheDecks;

end;


procedure SaveInstrument(Broker: TRPCBroker;
  InstrumentName,
  PatientDFN,
  OrderedByDUZ,
  AdministeredByDUZ,
  AdminDate, // FileMan format
  LocationIEN: string; // Add a "V" for Vista storage of temp file
  var Status: string); stdcall;
// The results of the adminstration were saved to a scratch file in Vista. That file is opened
// here and the temp data is saved to Vista.

var
  x                           : Integer;
  AdminID,
    lvLocationIEN,
    TempStr,
    Reply                     : string;
  TempStrList                 : TStringList;

  procedure ClearTheDecks;
  begin
    if gvInstrument <> nil then
      gvInstrument.Free;
    if TempStrList <> nil then
      TempStrList.Free;
    UponClosing(Broker);
  end;

  function CheckOutAnswers: boolean;
  var
    ii                        : integer;
  begin
    result := false;
    for ii := 0 to TempStrList.Count - 1 do
      begin
        if StrToBool(Piece(TempStrList[ii], U, 5)) then // Multi-Choice
          begin
            if (Piece(TempStrList[ii], U, 1) = '') or
              (Piece(TempStrList[ii], U, 2) = '') then
              exit;
          end;
      end;
    result := true;
  end;

begin
  lvLocationIEN := LocationIEN;

  x := Pos('V', lvLocationIEN);
  if x > 0 then
    begin
      gvSaveTempToVista := True;
      Delete(lvLocationIEN, x, 1);
    end
  else
    gvSaveTempToVista := False;

  TempStrList := TStringList.Create;

  if gvSaveTempToVista then
    begin
      if not ReadAnswersFromTempForList(Broker, PatientDFN, InstrumentName, TempStrList) then
        begin
          MsgDlgFrm(
            'Sorry, a serious error has occurred. ' + #13 +
            'The data to be saved can not be found.' + #13 +
            Reply + #13 +
            'Please contact your local IRM or CPRS expert if this ' +
            'problem persists.',
            MHA_DLL_CAPTION, mtError, [mbOK], 0);

          ClearTheDecks;
          Exit;
        end;
    end
  else
    begin
      gvFileName := GetFileName(PatientDFN, InstrumentName);

      if not FileExists(gvFileName) then
        begin
          Status := 'TEMP FILE NOT FOUND. NOTHING SAVED.';
          MsgDlgFrm(
            'Sorry, a serious error has occurred. ' + #13 +
            'A file can not be found in the Windows temporary directory: ' +
            gvFileName + #13 +
            'Please contact your local IRM or CPRS expert if this ' +
            'problem persists.',
            MHA_DLL_CAPTION, mtError, [mbOK], 0);
          UponClosing(Broker);
          Exit;
        end;

      TempStrList.LoadFromFile(gvFileName);
    end;

  // This will have the GAF score and the date of evaluation.
  if InstrumentName = 'GAF' then
    begin
      if gvSaveTempToVista then
        TempStr := Piece(TempStrList[0], U, 2)
      else
        TempStr := Piece(TempStrList[0], U, 1);

      Reply := WriteNewGAFRating(Broker, PatientDFN, OrderedByDUZ,
        AdminDate, // FileMan format
        TempStr);

      if Reply <> OK then
        begin
          MsgDlgFrm(
            'Sorry, a serious error has occurred. ' + #13 +
            'Saving the GAF score has produced an error.' + #13 +
            Reply + #13 +
            'Please contact your local IRM or CPRS expert if this ' +
            'problem persists.',
            MHA_DLL_CAPTION, mtError, [mbOK], 0);
          Status := 'GAF NOT SAVED';
        end
      else
        begin
          Status := 'GAF SAVED';

          if gvSaveTempToVista then
            RemoveTemp(Broker, InstrumentName, PatientDFN)
          else
            RemoveFiles;
        end;

      TempStrList.Free;
      UponClosing(Broker);
      Exit;
    end;

  gvInstrument := TInstrument.Create;
  gvInstrument.InstrumentName := InstrumentName;

  // Instrument, in turn creates the Objects; Questions, Introductions, Sections,
  //   Rules, Answers, Scales and Keys.
  if not DLL_Instrument_OPS.LoadDescriptiveProperties(Broker, gvInstrument) then
    begin
      Status := 'The Mental Health DLL was unable to load instrument-object.';
      MsgDlgFrm(
        'Sorry, a serious error has occurred. ' + #13 +
        'A call to YS Broker1, YTQ TSLIST1, produced an error. This may be ' +
        'due to not having the YS Broker1 properly set in VistA. ' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists.',
        MHA_DLL_CAPTION, mtError, [mbOK], 0);
      ClearTheDecks;
      Exit;
    end;

  // Returns the Administration ID if working properly, uMHA_DLL_Vista_IO
  AdminID := '';

  // Final check...
  if (PatientDFN = '') or
    (OrderedByDUZ = '') or
    (AdministeredByDUZ = '') or
    (lvLocationIEN = '') or
    (AdminDate = '') then
    begin
      Status := 'Administrative file, 601.84, not saved. ';
      ShowMessage(
      //MsgDlgFrm(
        'Sorry, a serious error has occurred. ' + #13 +
        'A blank value exists for one of these fields: ' + #13 +
        'Patient ID, Ordered by, Administered by, location or ' +
        'date.'); //,        MHA_DLL_CAPTION, mtError, [mbOK], 0);

      ClearTheDecks;
      Exit;
    end;

  if not CheckOutAnswers then
  // Look for blank answer fields in multiple-choice questions. These cause OBX
  // errors with HL7 messages.
    begin
      Status := 'Administrative file, 601.84, not saved. ';
      //MsgDlgFrm(
      ShowMessage(
        'Sorry, a serious error has occurred. ' + #13 +
        'The one or more of answers for this instrument contains a blank field.' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists. ' + #13 + Reply);
       // MHA_DLL_CAPTION, mtError, [mbOK], 0);

      ClearTheDecks;
      Exit;
    end;

  Reply := SaveAdministration(Broker, gvInstrument.InstrumentName, PatientDFN,
    OrderedByDUZ, AdministeredByDUZ, lvLocationIEN,
    AdminDate, // FileMan format: no checking needed
    IntToStr(TempStrList.count));

  if Pos(BAD_DATA, Reply) = 0 then
    begin
      Status := 'SAVED 601.84 ';
      AdminID := Reply;
    end
  else
    begin
      Status := 'Administrative file, 601.84, not saved. ';
      //MsgDlgFrm(
      ShowMessage(
        'Sorry, a serious error has occurred. ' + #13 +
        'Saving data to file 601.84 has produced an error.' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists. ' + #13 + Reply);
       // MHA_DLL_CAPTION, mtError, [mbOK], 0);

      ClearTheDecks;
      Exit;
    end;

  if WriteAnswers(Broker, AdminID, TempStrList) then
    begin
      Status := 'COMPLETE: ' + Status + 'AND 601.85.';

      if gvSaveTempToVista then
        RemoveTemp(Broker, gvInstrument.InstrumentName, PatientDFN);
    end
  else
    begin
      Status := 'ERROR: ' + Status + 'BUT NOT SAVED 601.85.';
      ShowMessage(
        'Sorry, a serious error has occurred. ' + #13 +
        'Saving data to file 601.85 has produced an error.' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists.');
       // MHA_DLL_CAPTION, mtError, [mbOK], 0);
      ClearTheDecks;
      Exit;
    end;

  SaveScore(AdminID, Broker);

(*
  reply := SendHL7Message(Broker, AdminID);// no longer used

  if reply <> DATA then
    begin
      Status := Status + #13 + 'ERROR: HL7 message not sent.';
      //MsgDlgFrm(
      ShowMessage(
        'Sorry, an error has occurred. ' + #13 +
        'The data from this instrument was not properly transmitted ' +
        'the national database via HL7 message.' + #13 +
        'Please contact your local IRM or CPRS expert if this ' +
        'problem persists.');
        //MHA_DLL_CAPTION, mtError, [mbOK], 0);
    end;*)

  if not gvSaveTempToVista then
    RemoveFiles;

  ClearTheDecks;
end;

procedure RemoveTempFile(
  InstrumentName, // if blank, all instruments are removed for patient
  PatientDFN: string); stdcall;
var
  SearchRec                   : TSearchRec;
  TempDir,
    TempFileName              : string;
begin
// Format is:
// GetTempDir +
//    IntToStr(DateTimeToFileDate(Date)) + FILE_NAME_DELIMITER +
//    PatientDFN + FILE_NAME_DELIMITER +
//    InstrumentName + '.mha';
  TempDir := GetTempDir;

  if InstrumentName = '' then
    begin
      if FindFirst(TempDir + '*.mha', faAnyFile, SearchRec) = 0 then
        begin
          repeat
            TempFileName := ExtractFileName(SearchRec.Name);

            if PatientDFN = Piece(TempFileName, FILE_NAME_DELIMITER, 2) then
              DeleteFile(TempDir + SearchRec.Name)

          until FindNext(SearchRec) <> 0;
          FindClose(SearchRec);
        end;
    end
  else
    if FileExists(TempDir + IntToStr(DateTimeToFileDate(Date)) +
      FILE_NAME_DELIMITER + PatientDFN + FILE_NAME_DELIMITER +
      InstrumentName + '.mha') then
      DeleteFile(TempDir + IntToStr(DateTimeToFileDate(Date)) +
        FILE_NAME_DELIMITER + PatientDFN + FILE_NAME_DELIMITER +
        InstrumentName + '.mha');
end;


procedure RemoveTempVistaFile(
  Broker: TRPCBroker;
  InstrumentName, // if blank, all instruments are removed for patient
  PatientDFN: string); stdcall;
begin
  RemoveTemp(Broker, InstrumentName, PatientDFN);
end;

end.

